summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorteor <teor2345@gmail.com>2016-12-07 15:58:57 +1100
committerteor <teor2345@gmail.com>2016-12-19 15:05:49 +1100
commit124c342364a354608a6569fa79192c0f92a7f6f5 (patch)
tree7b13eb29fb5e48a66d3e74c314cfba5c2a80837a /scripts
parent35da99a7122fc056f7b57650a52f556aa67cf251 (diff)
downloadtor-124c342364a354608a6569fa79192c0f92a7f6f5.tar.gz
tor-124c342364a354608a6569fa79192c0f92a7f6f5.zip
Reduce fallback bandwidth requirement to 1 MByte/s
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/maint/updateFallbackDirs.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/maint/updateFallbackDirs.py b/scripts/maint/updateFallbackDirs.py
index c3488fa9a2..a7c86d09a9 100755
--- a/scripts/maint/updateFallbackDirs.py
+++ b/scripts/maint/updateFallbackDirs.py
@@ -191,12 +191,12 @@ MAX_FALLBACKS_PER_FAMILY = 3
EXIT_BANDWIDTH_FRACTION = 1.0
# If a single fallback's bandwidth is too low, it's pointless adding it
# We expect fallbacks to handle an extra 30 kilobytes per second of traffic
# Make sure they can support a hundred times the expected extra load
# (Use 102.4 to make it come out nicely in MByte/s)
# We convert this to a consensus weight before applying the filter,
# because all the bandwidth amounts are specified by the relay
-MIN_BANDWIDTH = 102.4 * 30.0 * 1024.0
+MIN_BANDWIDTH = 102.4 * 10.0 * 1024.0
# Clients will time out after 30 seconds trying to download a consensus
# So allow fallback directories half that to deliver a consensus
@@ -191,12 +191,12 @@ MAX_FALLBACKS_PER_FAMILY = 3
EXIT_BANDWIDTH_FRACTION = 1.0
# If a single fallback's bandwidth is too low, it's pointless adding it
-# We expect fallbacks to handle an extra 30 kilobytes per second of traffic
+# We expect fallbacks to handle an extra 10 kilobytes per second of traffic
# Make sure they can support a hundred times the expected extra load
# (Use 102.4 to make it come out nicely in MByte/s)